@@ -552,6 +552,7 @@ a_dict = {
 }
 
 # Regression test for https://github.com/psf/black/issues/3506.
+# Regressed again by https://github.com/psf/black/pull/4498
 s = (
     "With single quote: ' "
     f" {my_dict['foo']}"
@@ -1239,9 +1240,15 @@ a_dict = {
 }
 
 # Regression test for https://github.com/psf/black/issues/3506.
-s = f"With single quote: '  {my_dict['foo']} With double quote: \"  {my_dict['bar']}"
+# Regressed again by https://github.com/psf/black/pull/4498
+s = (
+    "With single quote: ' "
+    f" {my_dict['foo']}"
+    ' With double quote: " '
+    f' {my_dict["bar"]}'
+)
 
 s = (
     "Lorem Ipsum is simply dummy text of the printing and typesetting"
-    f" industry:'{my_dict['foo']}'"
-)
+    f' industry:\'{my_dict["foo"]}\''
+)
\ No newline at end of file
